@@ -1,6 +1,5 @@
 package Bio::DB::SeqFeature::Store::Loader;
 
-# $Id$
 
 =head1 NAME
 
@@ -12,8 +11,8 @@ Bio::DB::SeqFeature::Store::Loader -- Loader
 
 =head1 DESCRIPTION
 
-This is the base class for Bio::DB::SeqFeature::GFF3Loader,
-Bio::DB::SeqFeature::GFFLoader, and
+This is the base class for Bio::DB::SeqFeature::Loader::GFF3Loader,
+Bio::DB::SeqFeature::Loader::GFFLoader, and
 Bio::DB::SeqFeature::FeatureFileLoader. Please see the manual pages
 for these modules.
 
@@ -53,7 +52,7 @@ pairs as described in this table:
  Name               Value
  ----               -----
 
- -store             A writeable Bio::DB::SeqFeature::Store database handle.
+ -store             A writable Bio::DB::SeqFeature::Store database handle.
 
  -seqfeature_class  The name of the type of Bio::SeqFeatureI object to create
                       and store in the database (Bio::DB::SeqFeature by default)
@@ -73,7 +72,10 @@ pairs as described in this table:
  -map_coords        A code ref that will transform a list of ($ref,[$start1,$end1]...)
                        coordinates into a list of ($newref,[$newstart1,$newend1]...)
 
- -index_subfeatures Indicate true if subfeatures should be indexed. Default is false.
+ -index_subfeatures Indicate true if subfeatures should be indexed. Default is true.
+
+ -summary_stats     Rebuild summary stats at the end of loading (not incremental,
+                     so takes a long time)
 
 When you call new(), a connection to a Bio::DB::SeqFeature::Store
 database should already have been established and the database
@@ -111,7 +113,7 @@ default.
 sub new {
   my $self = shift;
   my ($store,$seqfeature_class,$tmpdir,$verbose,$fast,
-      $seq_chunk_size,$coordinate_mapper,$index_subfeatures) = 
+      $seq_chunk_size,$coordinate_mapper,$index_subfeatures,$summary_stats) = 
       rearrange(['STORE',
 		 ['SF_CLASS','SEQFEATURE_CLASS'],
 		 ['TMP','TMPDIR'],
@@ -120,8 +122,10 @@ sub new {
 		 'CHUNK_SIZE',
 		 'MAP_COORDS',
 		 'INDEX_SUBFEATURES',
+		 'SUMMARY_STATS'
 		],@_);
 
+
   $seqfeature_class ||= $self->default_seqfeature_class;
   eval "require $seqfeature_class" unless $seqfeature_class->can('new');
   $self->throw($@) if $@;
@@ -144,15 +148,25 @@ END
   # try to bring in highres time() function
   eval "require Time::HiRes";
 
-  $tmpdir ||= File::Spec->tmpdir();
-  my $dsn = tempdir(DIR=>$tmpdir,CLEANUP=>1);
+  $tmpdir      ||= File::Spec->tmpdir();
 
-  my $tmp_store = Bio::DB::SeqFeature::Store->new(-adaptor  => 'berkeleydb',
-						  -temporary=> 1,
-						  -dsn      => $dsn,
-						  -cache    => 1,
-						  -write    => 1)
-    unless $normalized;
+  my ($tmp_store,$temp_load);
+  unless ($normalized) {
+
+      # remember the temporary directory in order to delete it on exit
+      $temp_load = tempdir(
+	  'BioDBSeqFeature_XXXXXXX',
+	  DIR=>$tmpdir,
+	  CLEANUP=>1
+	  );
+
+      $tmp_store = Bio::DB::SeqFeature::Store->new(-adaptor  => 'berkeleydb',
+						      -temporary=> 1,
+						      -dsn      => $temp_load,
+						      -cache    => 1,
+						      -write    => 1)
+	  unless $normalized;
+  }
 
   $index_subfeatures = 1 unless defined $index_subfeatures;
 
@@ -165,10 +179,12 @@ END
 		verbose          => $verbose,
 		load_data        => {},
 		tmpdir           => $tmpdir,
+		temp_load        => $temp_load,
 		subfeatures_normalized => $normalized,
 		subfeatures_in_table   => $in_table,
 		coordinate_mapper      => $coordinate_mapper,
 		index_subfeatures      => $index_subfeatures,
+		summary_stats          => $summary_stats,
 	       },ref($self) || $self;
 }
 
@@ -186,6 +202,14 @@ sub index_subfeatures {
     $d;
 }
 
+
+sub summary_stats {
+    my $self = shift;
+    my $d    = $self->{summary_stats};
+    $self->{summary_stats} = shift if @_;
+    $d;
+}
+
 =head2 load
 
  Title   : load
@@ -219,6 +243,14 @@ sub load {
     $count += $self->load_fh($fh);
     $self->msg(sprintf "load time: %5.2fs\n",$self->time()-$start);
   }
+  
+  if ($self->summary_stats) {
+      $self->msg("Building summary statistics for coverage graphs...");
+      my $start = $self->time();
+      $self->build_summary;
+      $self->msg(sprintf "coverage graph build time: %5.2fs\n",$self->time()-$start);
+  }
+  $self->msg(sprintf "total load time: %5.2fs\n",$self->time()-$start);
   $count;
 }
 
@@ -362,9 +394,25 @@ sub finish_load {
     $self->{load_data}{start_time} = $self->time();
     $self->store->finish_bulk_update;
   }
-  eval {$self->store->commit};
   $self->msg(sprintf "%5.2fs\n",$self->time()-$self->{load_data}{start_time});
-  $self->delete_load_data;
+  eval {$self->store->commit};
+
+  # don't delete load data so that caller can ask for the loaded IDs
+  # $self->delete_load_data;
+}
+
+=item build_summary
+
+  $loader->build_summary
+
+Call this to rebuild the summary coverage statistics. This is done automatically
+if new() was passed a true value for -summary_stats at create time.
+
+=cut
+
+sub build_summary {
+    my $self = shift;
+    $self->store->build_summary_statistics;
 }
 
 =item do_load
@@ -468,7 +516,6 @@ database. It uses a data structure stored in $self-E<gt>{load_data}.
 
 =cut
 
-
 sub store_current_feature {
   my $self    = shift;
 
@@ -608,6 +655,40 @@ sub msg {
   print STDERR @msg;
 }
 
+=item loaded_ids
+
+ my $ids    = $loader->loaded_ids;
+ my $id_cnt = @$ids;
+
+After performing a load, this returns an array ref containing all the
+feature primary ids that were created during the load.
+
+=cut
+
+sub loaded_ids {
+    my $self = shift;
+    my @ids  = values %{$self->{load_data}{Local2GlobalID}}
+                     if $self->{load_data};
+    return \@ids;
+}
+
+=item local_ids
+
+ my $ids    = $self->local_ids;
+ my $id_cnt = @$ids;
+
+After performing a load, this returns an array ref containing all the
+load file IDs that were contained within the file just loaded.
+
+=cut
+
+sub local_ids {
+    my $self = shift;
+    my @ids  = keys %{$self->{load_data}{Local2GlobalID}}
+                   if $self->{load_data};
+    return \@ids;
+}
+
 =item time
 
  my $time = $loader->time
@@ -637,6 +718,13 @@ sub unescape {
     return $todecode;
 }
 
+sub DESTROY {
+    my $self = shift;
+    if (my $ld = $self->{temp_load}) {
+	unlink $ld;
+    }
+}
+
 1;
 __END__
 
@@ -653,7 +741,7 @@ L<bioperl>,
 L<Bio::DB::SeqFeature::Store>,
 L<Bio::DB::SeqFeature::Segment>,
 L<Bio::DB::SeqFeature::NormalizedFeature>,
-L<Bio::DB::SeqFeature::GFF3Loader>,
+L<Bio::DB::SeqFeature::Store::GFF3Loader>,
 L<Bio::DB::SeqFeature::Store::DBI::mysql>,
 L<Bio::DB::SeqFeature::Store::berkeleydb>
 
