@@ -1,10 +1,11 @@
 #-----------------------------------------------------------------
-# $Id: PsiBlastHit.pm 14672 2008-04-22 21:42:50Z cjfields $
 #
 # BioPerl module Bio::Search::Hit::PsiBlastHit
 #
 # (This module was originally called Bio::Tools::Blast::Sbjct)
 #
+# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+#
 # Cared for by Steve Chervitz <sac@bioperl.org>
 #
 # You may distribute this module under the same terms as perl itself
@@ -88,9 +89,7 @@ The results of the HSP tiling is reported with the following ambiguity codes:
 
 
 For addition information about ambiguous BLAST alignments, see
-L<Bio::Search::BlastUtils::tile_hsps()|Bio::Search::BlastUtils> and
-
- http://www-genome.stanford.edu/Sacch3D/help/ambig_aln.html
+L<Bio::Search::BlastUtils::tile_hsps()|Bio::Search::BlastUtils>
 
 =head1 DEPENDENCIES
 
@@ -156,13 +155,24 @@ of the Bioperl mailing lists.  Your participation is much appreciated.
   bioperl-l@bioperl.org                  - General discussion
   http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
+=head2 Support 
+
+Please direct usage questions or support issues to the mailing list:
+
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
+
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-    http://bugzilla.open-bio.org/
+    https://redmine.open-bio.org/projects/bioperl/
 
 =head1 AUTHOR
 
