@@ -1,4 +1,3 @@
-# $Id: psl.pm 16123 2009-09-17 12:57:27Z cjfields $
 #
 # BioPerl module for Bio::SearchIO::psl
 #
@@ -62,7 +61,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://redmine.open-bio.org/projects/bioperl/
 
 =head1 AUTHOR - Jason Stajich
 
@@ -86,7 +85,7 @@ use Bio::Search::Hit::HitFactory;
 use Bio::Search::Result::ResultFactory;
 
 $DefaultProgramName   = 'BLAT';
-$DEFAULT_WRITER_CLASS = 'Bio::Search::Writer::HitTableWriter';
+$DEFAULT_WRITER_CLASS = 'Bio::SearchIO::Writer::HitTableWriter';
 
 # mapping of terms to Bioperl hash keys
 %MODEMAP = (
