@@ -1,7 +1,8 @@
-# $Id: GenericRichSeqHandler.pm 15212 2008-12-19 05:47:58Z cjfields $
 #
 # BioPerl module for Bio::SeqIO::Handler::GenericRichSeqHandler
 #
+# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+#
 # Cared for by Chris Fields
 #
 # Copyright Chris Fields
@@ -105,17 +106,28 @@ of the Bioperl mailing lists.  Your participation is much appreciated.
   bioperl-l@bioperl.org                  - General discussion
   http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
+=head2 Support 
+
+Please direct usage questions or support issues to the mailing list:
+
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
+
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution.  Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://redmine.open-bio.org/projects/bioperl/
 
-=head1 AUTHOR - Ewan Birney
+=head1 AUTHOR - Chris Fields
 
-Email cjfields at uiuc dot edu
+Email cjfields at bioperl dot org
 
 =head1 APPENDIX
 
@@ -155,6 +167,7 @@ my %HANDLERS = (
         'VERSION'       => \&_generic_version,
         'KEYWORDS'      => \&_generic_keywords,
         'DBSOURCE'      => \&_genbank_dbsource,
+        'DBLINK'        => \&_genbank_dbsource,
         'SOURCE'        => \&_generic_species,
         'REFERENCE'     => \&_generic_reference,
         'COMMENT'       => \&_generic_comment,
@@ -213,7 +226,7 @@ my %DBSOURCE = map {$_ => 1} qw(
     TMHOBP    COMPLUYEAST-2DPAGE    OGP    DictyBase    HAMAP
     PhotoList    Gramene    WormBase    WormPep    Genew    ZFIN
     PeroxiBase    MaizeDB    TAIR    DrugBank    REBASE    HPA
-    swissprot    GenBank    GenPept    REFSEQ    embl    PDB);
+    swissprot    GenBank    GenPept    REFSEQ    embl    PDB    UniProtKB);
 
 my %NOPROCESS = map {$_ => 1} qw(DBSOURCE ORGANISM FEATURES);
 
@@ -861,12 +874,12 @@ sub _genbank_dbsource {
     my $annotation = $self->annotation_collection;
     # deal with swissprot dbsources
     # we could possibly parcel these out to subhandlers...
-    if( $dbsource =~ s/swissprot:\s+locus\s+(\S+)\,.+\n// ) {
+    if( $dbsource =~ s/(UniProt(?:KB)|swissprot):\s+locus\s+(\S+)\,.+\n// ) {
         $annotation->add_Annotation
-            ('d blink',
+            ('dblink',
              Bio::Annotation::DBLink->new
-             (-primary_id => $1,
-              -database => 'swissprot',
+             (-primary_id => $2,
+              -database => $1,
               -tagname => 'dblink'));
         if( $dbsource =~ s/\s*created:\s+([^\.]+)\.\n// ) {
             $annotation->add_Annotation
@@ -962,15 +975,20 @@ sub _genbank_dbsource {
               -version => $version,
               -database => $db || 'GenBank',
               -tagname => 'dblink'));
-        } elsif ( $dbsource =~ /(\S+)\.(\d+)/ ) {
-            my ($id,$version) = ($1,$2);
-            $annotation->add_Annotation
-            ('dblink',
-             Bio::Annotation::DBLink->new
-             (-primary_id => $id,
-              -version => $version,
-              -database => 'GenBank',
-              -tagname => 'dblink'));
+        } elsif ( $dbsource =~ /(\S+)([\.:])(\d+)/ ) {
+            my ($id, $db, $version);
+            if ($2 eq ':') {
+                ($db, $id) = ($1, $3);
+            } else {
+                ($db, $id, $version) = ('GenBank', $1, $3);
+            }
+            $annotation->add_Annotation('dblink',
+                Bio::Annotation::DBLink->new(
+                    -primary_id => $id,
+                    -version => $version,
+                    -database => $db,
+                    -tagname => 'dblink')
+                );
         } else {
             $self->warn("Unrecognized DBSOURCE data: $dbsource\n");
         }
@@ -1110,7 +1128,10 @@ sub _generic_seqfeatures {
 
 ####################### ODDS AND ENDS #######################
 
-# Those things that don't fit anywhere else...
+# Those things that don't fit anywhere else.  If a specific name 
+# maps to the below table, that class and method are used, otherwise
+# it goes into a SimpleValue (I think this is a good argument for why
+# we need a generic mechanism for storing annotation)
 
 sub _generic_simplevalue {
     my ($self, $data) = @_;
